"use client"

import { useState } from "react"
import LoadingSpinner from "@/components/loading-spinner"
import LoadingSpinnerVariants from "@/components/loading-spinner-variants"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Label } from "@/components/ui/label"
import { Switch } from "@/components/ui/switch"
import { Input } from "@/components/ui/input"

export default function DemoSpinners() {
    const [size, setSize] = useState<"sm" | "md" | "lg">("md")
    const [message, setMessage] = useState("Loading...")
    const [showMessage, setShowMessage] = useState(true)
    const [fullHeight, setFullHeight] = useState(false)

    return (
        <div className="container mx-auto py-8 px-4">
            <h1 className="text-2xl font-bold mb-6 text-slate-800 dark:text-slate-200">Loading Spinner Components</h1>

            <div className="grid grid-cols-1 lg:grid-cols-3 gap-6 mb-8">
                <Card className="col-span-1">
                    <CardHeader>
                        <CardTitle>Spinner Settings</CardTitle>
                        <CardDescription>Customize the loading spinner appearance</CardDescription>
                    </CardHeader>
                    <CardContent className="space-y-4">
                        <div className="space-y-2">
                            <Label htmlFor="size">Size</Label>
                            <Select value={size} onValueChange={(value) => setSize(value as "sm" | "md" | "lg")}>
                                <SelectTrigger id="size">
                                    <SelectValue placeholder="Select size" />
                                </SelectTrigger>
                                <SelectContent>
                                    <SelectItem value="sm">Small</SelectItem>
                                    <SelectItem value="md">Medium</SelectItem>
                                    <SelectItem value="lg">Large</SelectItem>
                                </SelectContent>
                            </Select>
                        </div>

                        <div className="space-y-2">
                            <Label htmlFor="message">Message</Label>
                            <Input
                                id="message"
                                value={message}
                                onChange={(e) => setMessage(e.target.value)}
                                disabled={!showMessage}
                            />
                        </div>

                        <div className="flex items-center space-x-2">
                            <Switch id="show-message" checked={showMessage} onCheckedChange={setShowMessage} />
                            <Label htmlFor="show-message">Show message</Label>
                        </div>

                        <div className="flex items-center space-x-2">
                            <Switch id="full-height" checked={fullHeight} onCheckedChange={setFullHeight} />
                            <Label htmlFor="full-height">Full height</Label>
                        </div>
                    </CardContent>
                </Card>

                <Card className="col-span-1 lg:col-span-2">
                    <CardHeader>
                        <CardTitle>Preview</CardTitle>
                        <CardDescription>Different spinner variants</CardDescription>
                    </CardHeader>
                    <CardContent>
                        <Tabs defaultValue="default">
                            <TabsList className="grid grid-cols-4 mb-4">
                                <TabsTrigger value="default">Default</TabsTrigger>
                                <TabsTrigger value="dots">Dots</TabsTrigger>
                                <TabsTrigger value="circular">Circular</TabsTrigger>
                                <TabsTrigger value="pulse">Pulse</TabsTrigger>
                            </TabsList>

                            <TabsContent value="default" className="border rounded-md h-64 flex items-center justify-center">
                                <LoadingSpinner size={size} message={showMessage ? message : undefined} fullHeight={fullHeight} />
                            </TabsContent>

                            <TabsContent value="dots" className="border rounded-md h-64 flex items-center justify-center">
                                <LoadingSpinnerVariants
                                    variant="dots"
                                    size={size}
                                    message={showMessage ? message : undefined}
                                    fullHeight={fullHeight}
                                />
                            </TabsContent>

                            <TabsContent value="circular" className="border rounded-md h-64 flex items-center justify-center">
                                <LoadingSpinnerVariants
                                    variant="circular"
                                    size={size}
                                    message={showMessage ? message : undefined}
                                    fullHeight={fullHeight}
                                />
                            </TabsContent>

                            <TabsContent value="pulse" className="border rounded-md h-64 flex items-center justify-center">
                                <LoadingSpinnerVariants
                                    variant="pulse"
                                    size={size}
                                    message={showMessage ? message : undefined}
                                    fullHeight={fullHeight}
                                />
                            </TabsContent>
                        </Tabs>
                    </CardContent>
                </Card>
            </div>

            <Card>
                <CardHeader>
                    <CardTitle>Usage</CardTitle>
                    <CardDescription>How to use the loading spinner components</CardDescription>
                </CardHeader>
                <CardContent>
                    <pre className="bg-slate-100 dark:bg-slate-800 p-4 rounded-md overflow-x-auto text-sm">
                        {`// Basic usage
import LoadingSpinner from "@/components/loading-spinner"

export default function MyComponent() {
  return <LoadingSpinner />
}

// With custom props
import LoadingSpinner from "@/components/loading-spinner"

export default function MyComponent() {
  return (
    <LoadingSpinner 
      size="lg" 
      message="Please wait..." 
      fullHeight={false} 
    />
  )
}

// Using variants
import LoadingSpinnerVariants from "@/components/loading-spinner-variants"

export default function MyComponent() {
  return (
    <LoadingSpinnerVariants 
      variant="dots" 
      size="md" 
      message="Loading data..." 
    />
  )
}`}
                    </pre>
                </CardContent>
            </Card>
        </div>
    )
}
